(installation-index)=

# Installation

vLLM supports the following hardware platforms:

:::{toctree}
:maxdepth: 1
:hidden:

installation/gpu
installation/cpu
installation/ai_accelerator
:::

- <project:installation/gpu.md>
  - NVIDIA CUDA
  - AMD ROCm
  - Intel XPU
- <project:installation/cpu.md>
  - Intel/AMD x86
  - ARM AArch64
  - Apple silicon
  - IBM Z (S390X)
- <project:installation/ai_accelerator.md>
  - Google TPU
  - Intel Gaudi
  - AWS Neuron
